.. image:: https://github.com/timcera/tstoolbox/actions/workflows/python-package.yml/badge.svg
    :alt: Tests
    :target: https://github.com/timcera/tstoolbox/actions/workflows/python-package.yml
    :height: 20

.. image:: https://img.shields.io/coveralls/github/timcera/tstoolbox
    :alt: Test Coverage
    :target: https://coveralls.io/r/timcera/tstoolbox?branch=master
    :height: 20

.. image:: https://img.shields.io/pypi/v/tstoolbox.svg
    :alt: Latest release
    :target: https://pypi.python.org/pypi/tstoolbox/
    :height: 20

.. image:: http://img.shields.io/pypi/l/tstoolbox.svg
    :alt: BSD-3 clause license
    :target: https://pypi.python.org/pypi/tstoolbox/
    :height: 20

.. image:: http://img.shields.io/pypi/dd/tstoolbox.svg
    :alt: tstoolbox downloads
    :target: https://pypi.python.org/pypi/tstoolbox/
    :height: 20

.. image:: https://img.shields.io/pypi/pyversions/tstoolbox
    :alt: PyPI - Python Version
    :target: https://pypi.org/project/tstoolbox/
    :height: 20
